package com.idiot.operationbackend.service.impl;

import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.idiot.operationbackend.entity.AccountFans;
import com.idiot.operationbackend.mappers.AccountFansMapper;
import com.idiot.operationbackend.service.facade.AccountFansService;
import com.idiot.operationbackend.support.Constants;
import com.idiot.operationbackend.vo.NumberStatData;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author wang xiao
 * @date Created in 19:24 2020/9/10
 */
@Service
public class AccountFansServiceImpl extends ServiceImpl<AccountFansMapper, AccountFans>
        implements AccountFansService {


    @Override
    public AccountFans queryByAccountIdAndOpenId(String accountId, String openId) {
        return getOne(Wrappers.<AccountFans>lambdaQuery().eq(AccountFans::getAccountId,accountId)
                .eq(AccountFans::getOpenId,openId),false);
    }


    @Override
    public int countFansByAccountId(String accountId) {
        return count(Wrappers.<AccountFans>lambdaQuery().eq(AccountFans::getAccountId,accountId)
                .eq(AccountFans::getState,1));
    }


    @Override
    public List<AccountFans> queryFansByDateAndDate(String accountId, String startDate, String endDate) {
        long  end = Constants.toLocalDateTime(endDate).plusDays(1)
                .toEpochSecond(Constants.DEFAULT_ZONE);
        long  start =Constants.toLocalDateTime(endDate)
                .toEpochSecond(Constants.DEFAULT_ZONE);
        return list(Wrappers.<AccountFans>lambdaQuery()
                .eq(AccountFans::getAccountId,accountId)
                .eq(AccountFans::getState,1)
                .ge(AccountFans::getCreateTime,start)
                .le(AccountFans::getCreateTime,end));
    }


    @Override
    public List<NumberStatData> statByFansProperty(String accountId, String startDate, String endDate) {
        List<NumberStatData> numberStatData = null;
        if (StringUtils.isNotBlank(startDate) && StringUtils.isNotBlank(endDate)) {
            long start = Constants.toEpochSecond(Constants.toLocalDateTime(startDate));
            long end = Constants.toEpochSecond(Constants.toLocalDateTime(endDate).plusDays(1));
            numberStatData = baseMapper.statPropertyByDate(accountId,start,end);
        }else {
            numberStatData = baseMapper.statPropertyByAll(accountId);
        }
        return numberStatData;
    }
}
